changeset 732:c043f06fd143 draft

Updated.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Thu, 11 Jun 2015 14:18:29 +0200
parents ab752b2942ad
children 2de8cf02af41
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 58 insertions(+), 53 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Wed Jun 10 13:14:55 2015 +0200
+++ b/ChangeLog	Thu Jun 11 14:18:29 2015 +0200
@@ -1,3 +1,8 @@
+2015-06-11  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated.
+
 2015-06-09  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jun 10 13:14:55 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Jun 11 14:18:29 2015 +0200
@@ -12841,7 +12841,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -12850,13 +12850,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -12865,13 +12865,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -12880,13 +12880,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -12895,13 +12895,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -12910,13 +12910,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -12925,13 +12925,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -12940,13 +12940,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -12955,9 +12955,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexedBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.red);
+    public TestResult testBitBltGridBufferedImageTypeIntRGBbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntRGB(image, graphics2d, Color.red);
     }
 
     /**
@@ -12841,7 +12841,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.magenta.
      *